@@ -5,7 +5,7 @@ class DB():
     
     def __init__(self,dbname:str,debug=False):
         
-        self.db = sqlite3.connect(dbname+'.db')
+        self.db = sqlite3.connect(dbname)
         self.sql = self.db.cursor()
         self.debug = debug
         if self.debug == True:
